@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::SHARYANTO::Task::Private;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Dist::Zilla::PluginBundle::Filter;
 
@@ -12,7 +12,7 @@ sub configure {
 
     $self->add_bundle(Filter => {
         -bundle => '@SHARYANTO::Task',
-        -remove => [qw/ConfirmRelease UploadToCPAN/],
+        -remove => [qw/ConfirmRelease MetaJSON MetaYAML UploadToCPAN/],
     });
 }
 
@@ -31,7 +31,7 @@ Dist::Zilla::PluginBundle::SHARYANTO::Task::Private - Dist::Zilla like SHARYANTO
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -47,13 +47,15 @@ is equivalent to:
 
 =head1 DESCRIPTION
 
+=for Pod::Coverage ^(configure)$
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
